@@ -4,6 +4,7 @@
 # imports.
 from syst3m.classes.config import *
 from syst3m.classes import utils, console
+from syst3m.classes.env import env
 import platform 
 
 # vars.
@@ -15,6 +16,7 @@ vars = r3sponse.ResponseObject({
 	"media": f"/media/{os.environ.get('USER')}",
 	"homes": "/home/",
 	"home": f"/home/{os.environ.get('USER')}/",
+	"python3":"python3",
 })
 if vars.os in ["darwin"]:  
 	vars.os = "macos"
@@ -22,12 +24,14 @@ if vars.os in ["darwin"]:
 	vars.media = f"/Volumes/"
 	vars.homes = "/Users/"
 	vars.home = f"/Users/{vars.user}/"
+	vars.python3 = f"/usr/bin/python3"
 
 # universal options.
 options = r3sponse.ResponseObject({
-	"interactive": not cl1.arguments_present(["--non-interactive"]),
+	"interactive": not cl1.arguments_present(["--non-interactive"]) and env.get("INTERACTIVE", format=bool, default=False) == True,
+	"cli": env.get_boolean("CLI", default=False),
 	"json": cl1.arguments_present(["-j", "--json"]),
-	"log_level": int(cl1.get_argument("--log-level", required=False, default=0)),
+	"log_level": int(cl1.get_argument("--log-level", required=False, default=env.get_integer("LOG_LEVEL", default=0))),
 })
 
 # get operating system.
@@ -80,7 +84,7 @@ def source_path(path, back=1):
 
 # get log level.
 def log_level(default=0):
-	return int(cl1.get_argument("--log-level", required=False, default=default))
+	return int(cl1.get_argument("--log-level", required=False, default=env.get_integer("LOG_LEVEL", default=0)))
 
 # get current working directory.
 def pwd():
@@ -97,7 +101,7 @@ def kill(
 	# root permission required.
 	sudo=False,
 	# loader.
-	loader=True,
+	log_level=0,
 ):
 	# kill includes.
 	if includes != None:
@@ -117,11 +121,8 @@ def kill(
 
 	# kill pid.
 	else:
-		if loader:
-			log_level = 0
-			loader_ = console.Loader(f"Killing process {pid}.")
-		else:
-			log_level = -1
+		if log_level >= 0:
+			loader = console.Loader(f"Killing process {pid}.")
 		_sudo_ = Boolean(sudo).convert(true="sudo ", false="")
 		output = utils.__execute_script__(f"{_sudo_}kill {pid}")
 		if output in ["terminated",""]:
@@ -130,13 +131,13 @@ def kill(
 				if not response.success: response
 				try: 
 					response.processes[pid]
-					if loader: loader_.stop(success=False)
+					if log_level >= 0: loader.stop(success=False)
 					return r3sponse.error(f"Failed to stop process {pid}.", log_level=log_level)
 				except KeyError: a=1
-			if loader: loader_.stop()
+			if log_level >= 0: loader.stop()
 			return r3sponse.success(f"Successfully killed process {pid}.")
 		else:
-			if loader: loader_.stop(success=False)
+			if log_level >= 0: loader.stop(success=False)
 			return r3sponse.error(f"Failed to stop process {pid}, error: {output}", log_level=log_level)
 
 # list all processes.
@@ -145,24 +146,37 @@ def processes(
 	sudo=False,
 	# all processes that include a str.
 	includes=None,
+	# banned process names.
+	banned=["grep"],
 ):
 	_sudo_ = Boolean(sudo).convert(true="sudo ", false="")
 	if isinstance(includes, str):
 		command = f"""{_sudo_}ps -ax | grep "{includes}" | """
 	else:
 		command = f"""{_sudo_}ps -ax | """
-	output = utils.__execute_script__(command + """awk '{print $1"|"$2"|"$3"|"$4}' """)
+	#output = utils.__execute_script__(command + """awk '{print $1"|"$2"|"$3"|"$4"}' """)
+	output = utils.__execute_script__(command + """awk '{$3="";print $0}' """)
 	processes = {}
 	for line in output.split("\n"):
 		if line not in ["", " "]:
-			try:
-				pid,tty,_,process = line.split("|")
-			except ValueError: raise ValueError(f"Unable to unpack process line: [{line}], expected format: [4] seperator: [|].")
-			processes[pid] = {
-				"pid":pid,
-				"tty":tty,
-				"process":process,
-			}
+			array = line.split(" ")
+			pid = array.pop(0)
+			tty = array.pop(0)
+			for i in array:
+				process = array[0]
+				if process not in ["", " "]: break
+				else: array.pop(0)
+			command = Array(array).string(joiner=" ")
+			#try:
+			#	pid,tty,_,process,command = line.split("|")
+			#except ValueError: raise ValueError(f"Unable to unpack process line: [{line}], expected format: [4] seperator: [|].")
+			if process not in banned:
+				processes[pid] = {
+					"pid":pid,
+					"tty":tty,
+					"process":process,
+					"command":command,
+				}
 	return r3sponse.success(f"Successfully listed {len(processes)} processes.", {
 		"processes":processes,
 	})
